# vim: noexpandtab fileencoding=utf-8
# Copyright © 2008 Sabin Iacob (m0n5t3r) <iacobs-gs@m0n5t3r.info>
# 
# This file is part of gScrobbler.
#
# gScrobbler is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pygtk
pygtk.require('2.0')
import gtk
import getpass as gp

__all__ = ('get_credentials',)

class UserPassDialog:
	def ok_cb(self, w):
		self.username = self._user.get_text()
		self.password = self._pass.get_text()
		self.window.destroy()
		gtk.main_quit()
	
	def cancel_cb(self, w, e = None):
		if e is None or (e.type is gtk.gdk.KEY_PRESS and gtk.gdk.keyval_name(e.keyval) == 'Escape'):
			self.window.destroy()
			gtk.main_quit()
	
	def __init__(self):
		self.username = ''
		self.password = ''

		self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
		self.window.set_title(_('Last.fm credentials'))
		self.window.connect('delete_event', self.cancel_cb)
		self.window.connect('key-press-event', self.cancel_cb)

		vbox = gtk.VBox(False, 0)
		self.window.add(vbox)
		vbox.show()

		hbox = gtk.HBox(False, 0)
		vbox.add(hbox)
		hbox.show()

		self._user = gtk.Entry()
		self._user.set_max_length(50)
		self._user.set_activates_default(True)
		
		label = gtk.Label(_('_Username: '))
		label.set_use_underline(True)
		label.set_mnemonic_widget(self._user)
		label.set_alignment(1, 0.5)

		hbox.pack_end(self._user, False, True, 5)
		hbox.pack_end(label, True, True, 5)
		
		label.show()
		self._user.show()

		hbox = gtk.HBox(False, 0)
		vbox.add(hbox)
		hbox.show()

		self._pass = gtk.Entry()
		self._pass.set_max_length(50)
		self._pass.set_visibility(False)
		self._pass.set_activates_default(True)

		label = gtk.Label(_('_Password: '))
		label.set_use_underline(True)
		label.set_mnemonic_widget(self._pass)
		label.set_alignment(1, 0.5)

		hbox.pack_end(self._pass, False, True, 5)
		hbox.pack_end(label, True, True, 5)
		
		label.show()
		self._pass.show()

		hbox = gtk.HBox(True, 0)
		vbox.pack_end(hbox, True, True, 5)
		hbox.show()
							  
		button = gtk.Button(stock = gtk.STOCK_OK)
		button.connect('clicked', self.ok_cb)
		button.set_flags(gtk.CAN_DEFAULT)
		
		hbox.pack_start(button, True, True, 5)
		button.grab_default()
		button.show()

		button = gtk.Button(stock = gtk.STOCK_CANCEL)
		button.connect('clicked', self.cancel_cb)
		
		hbox.pack_start(button, True, True, 5)
		button.show()

	def __call__(self, username = '', password = ''):
		self.username = username
		self.password = password

		self._user.set_text(username)
		self._user.select_region(0, len(username))
		
		self._pass.set_text(password)
		self._pass.select_region(0, len(password))

		self.window.show()
		gtk.main()
		return self.username, self.password

get_credentials = UserPassDialog()

