# vim: noexpandtab fileencoding=utf-8
# Copyright © 2008 Sabin Iacob (m0n5t3r) <iacobs-gs@m0n5t3r.info>
# 
# This file is part of gScrobbler.
#
# gScrobbler is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re

import pynotify

pynotify.init('gScrobbler')
aid_re = re.compile('[\W]+')

__all__ = ('notify',)

def notify(txt, timeout = 3000, actions = (), onclose = None):
	"""build a pynotify.Notification object with the given timeout, text and actions 
	if onclose is given, it is connected to the "closed" gobject signal and the handler
	ID is passed to all the actions
	
	>>> def cb(n, a):
	...     print 'it worked!'
	...

	>>> n = notify('just testing', 5000, (('button test', cb),))

	>>> type(n)
	<type 'pynotify.Notification'>

	>>> n.show()
	True
	"""
	notif = pynotify.Notification('last.fm', str(txt), 'gnome-dev-ipod')
	notif.set_urgency(pynotify.URGENCY_LOW)
	notif.set_category('device')
	notif.set_timeout(timeout)

	ccb = None
	if callable(onclose):
		ccb = notif.connect('closed', onclose)
	
	notif.set_data('closed_id', ccb)

	for label, callback in actions:
		action_id = re.sub(aid_re, '', label.lower())
		notif.add_action(action_id, label, callback)
	return notif

